==> nessie-rest-services-0.71.0-sources.jar: org/projectnessie/services/rest/RestContentService.java <==
/*
 * Copyright (C) 2023 Dremio
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.projectnessie.services.rest;

import java.security.Principal;
import java.util.function.Supplier;
import javax.enterprise.context.RequestScoped;
import javax.inject.Inject;
import javax.validation.executable.ExecutableType;
import javax.validation.executable.ValidateOnExecution;
import org.projectnessie.services.authz.Authorizer;
import org.projectnessie.services.config.ServerConfig;
import org.projectnessie.services.impl.ContentApiImpl;
import org.projectnessie.versioned.VersionStore;

@RequestScoped
@jakarta.enterprise.context.RequestScoped
@ValidateOnExecution(type = ExecutableType.ALL)
@jakarta.validation.executable.ValidateOnExecution(
    type = jakarta.validation.executable.ExecutableType.ALL)
public class RestContentService extends ContentApiImpl {
  // Mandated by CDI 2.0
  public RestContentService() {
    this(null, null, null, null);
  }

  @Inject
  @jakarta.inject.Inject
  public RestContentService(
      ServerConfig config,
      VersionStore store,
      Authorizer authorizer,
      Supplier<Principal> principal) {
    super(config, store, authorizer, principal);
  }
}

==> nessie-rest-services-0.77.1-sources.jar: org/projectnessie/services/rest/RestContentService.java <==
/*
 * Copyright (C) 2023 Dremio
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.projectnessie.services.rest;

import jakarta.enterprise.context.RequestScoped;
import jakarta.inject.Inject;
import jakarta.validation.executable.ExecutableType;
import jakarta.validation.executable.ValidateOnExecution;
import java.security.Principal;
import java.util.function.Supplier;
import org.projectnessie.services.authz.Authorizer;
import org.projectnessie.services.config.ServerConfig;
import org.projectnessie.services.impl.ContentApiImpl;
import org.projectnessie.versioned.VersionStore;

@RequestScoped
@ValidateOnExecution(type = ExecutableType.ALL)
public class RestContentService extends ContentApiImpl {
  // Mandated by CDI 2.0
  public RestContentService() {
    this(null, null, null, null);
  }

  @Inject
  public RestContentService(
      ServerConfig config,
      VersionStore store,
      Authorizer authorizer,
      Supplier<Principal> principal) {
    super(config, store, authorizer, principal);
  }
}
